==> JVPC-0.93.zip: JVPC-0.93/vga/FC.java <==
// File: FC.java

package jvpc.vga;

/**
 * FC contains information about Friendly Codes
 *
 * @author Rutger Nijlunsing
 */
public class FC {
  /**
   * Returns true if friendly code fc is a special ship FC
   */
  public static boolean isShipSpecial(String fc) {
    if (fc == null)
      return false;
    
    // 3 letter FC's
    String spec3[]={
      "HYP", "NAL", "NTP", "WRT", "WRS", "alt", "ald", "alm", "bdm",
      "btt", "btf", "btm", "cln", "lfm", "mkt", "mdh", "mdq", "msc",
      "nad", "nat", "nam", "nbr", "pop", "trg"
    };
    for (int i=0; i<spec3.length; i++) {
      if (spec3[i].equals(fc))
	return true;
    }

    // 2 letter FC's
    String spec2[]={"md", "mi", "gs" };
    StringBuffer fc2 = new StringBuffer(fc);
    fc2.setLength(2); // FIXME: check this
    for (int i=0; i<spec2.length; i++) {
      if (spec2[i].equals(fc2))
	return true;
    }
    return false;
  }

  public static boolean isAlmostShipSpecial(String fc) {
    if (fc == null) 
      return false;
    if (isShipSpecial(fc))
      return false;
    StringBuffer lower = MyString.toLower(fc);
    if (isShipSpecial(lower.toString()))
      return true;
    StringBuffer upper = MyString.toUpper(fc);
    if (isShipSpecial(upper.toString()))
      return true;
    return false;
  }

  /**
   * Return true if friendly code fc is a special planet fc
   */
  public static boolean isPlanetSpecial(String fc) {
    if (fc == null)
      return false;

    String spec[]={"ATT", "NUK", "bum", "con", "dmp"};
    for (int i=0; i<spec.length; i++) {
      if (spec[i].equals(fc))
	return true;
    }
    return false;
  }

  public static boolean isAlmostPlanetSpecial(String fc) {
    if (fc == null)
      return false;

    if (isPlanetSpecial(fc))
      return false;
    StringBuffer lower = MyString.toLower(fc);
    if (isPlanetSpecial(lower.toString()))
      return true;
    StringBuffer upper = MyString.toUpper(fc);
    if (isPlanetSpecial(upper.toString()))
      return true;
    return false;
  }
}

==> JVPC-0.94.zip: JVPC-0.94/vga/FC.java <==
// File: FC.java

package jvpc.vga;

/**
 * FC contains information about Friendly Codes
 *
 * @author Rutger Nijlunsing
 */
public class FC {
  /**
   * Returns true if friendly code fc is a special ship FC
   */
  public static boolean isShipSpecial(String fc) {
    if (fc == null)
      return false;
    
    // 3 letter FC's
    String spec3[] = {
      "HYP", "NAL", "NTP", "WRT", "WRS", "alt", "ald", "alm", "bdm",
      "btt", "btf", "btm", "cln", "lfm", "mkt", "mdh", "mdq", "msc",
      "nad", "nat", "nam", "nbr", "pop", "trg"
    };
    for (int i=0; i<spec3.length; i++) {
      if (spec3[i].equals(fc))
	return true;
    }

    // 2 letter FC's
    String spec2[] = {
	"md", "mi", "gs", "ff", "FF", "ee", "EE", "mf", "mF", "Mf"
    };
    StringBuffer fc2 = new StringBuffer(fc);
    fc2.setLength(2); // FIXME: check this
    for (int i=0; i<spec2.length; i++) {
      if (spec2[i].equals(fc2))
	return true;
    }
    return false;
  }

  public static boolean isAlmostShipSpecial(String fc) {
    if (fc == null) 
      return false;
    if (isShipSpecial(fc))
      return false;
    StringBuffer lower = MyString.toLower(fc);
    if (isShipSpecial(lower.toString()))
      return true;
    StringBuffer upper = MyString.toUpper(fc);
    if (isShipSpecial(upper.toString()))
      return true;
    return false;
  }

  /**
   * Return true if friendly code fc is a special planet fc
   */
  public static boolean isPlanetSpecial(String fc) {
    if (fc == null)
      return false;

    String spec[]={"ATT", "NUK", "bum", "con", "dmp", "PB"};
    for (int i=0; i<spec.length; i++) {
      if (fc.startsWith(spec[i]))
	return true;
    }
    return false;
  }

  public static boolean isAlmostPlanetSpecial(String fc) {
    if (fc == null)
      return false;

    if (isPlanetSpecial(fc))
      return false;
    StringBuffer lower = MyString.toLower(fc);
    if (isPlanetSpecial(lower.toString()))
      return true;
    StringBuffer upper = MyString.toUpper(fc);
    if (isPlanetSpecial(upper.toString()))
      return true;
    return false;
  }
}
